define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"AH"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"eraNames@localeAlias1356": {
		"bundle": "islamic",
		"target": "eraAbbr"
	},
	"months@localeAlias1323": {
		"bundle": "islamic",
		"target": "months"
	},
	"field-quarter-narrow@localeAlias1371": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias1372": {
		"bundle": "",
		"target": "field-quarter"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-month-narrow@localeAlias1374": {
		"bundle": "",
		"target": "field-month-short"
	},
	"field-month-narrow@localeAlias1375": {
		"bundle": "",
		"target": "field-month"
	},
	"field-year-narrow@localeAlias1368": {
		"bundle": "",
		"target": "field-year-short"
	},
	"field-minute-narrow-relative+0": "this minute",
	"field-year-narrow@localeAlias1369": {
		"bundle": "",
		"target": "field-year"
	},
	"days-format-short@localeAlias1331": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-format-short@localeAlias1332": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"field-dayOfYear-short@localeAlias1385": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-wed-short@localeAlias1403": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-hour-relative+0": "this hour",
	"field-thu-short@localeAlias1406": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"months-format-narrow@localeAlias1324": {
		"bundle": "islamic",
		"target": "months-standAlone-narrow"
	},
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"days-standAlone-abbr@localeAlias1333": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-abbr@localeAlias1334": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-month": "Month",
	"months-standAlone-wide": [
		"Muharram",
		"Safar",
		"Rabiʻ I",
		"Rabiʻ II",
		"Jumada I",
		"Jumada II",
		"Rajab",
		"Shaʻban",
		"Ramadan",
		"Shawwal",
		"Dhuʻl-Qiʻdah",
		"Dhuʻl-Hijjah"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-year-relative+0": "this year",
	"field-weekday-short@localeAlias1388": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-year-relative+1": "next year",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-era-short@localeAlias1364": {
		"bundle": "",
		"target": "field-era"
	},
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-quarter-short@localeAlias1370": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-year-narrow": "Year",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"months-standAlone-abbr@localeAlias1325": {
		"bundle": "islamic",
		"target": "months-format-abbr"
	},
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-weekOfMonth-short@localeAlias1379": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-quarter-short-relative+-1": "last quarter",
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"field-minute-short@localeAlias1421": {
		"bundle": "",
		"target": "field-minute"
	},
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-second-narrow@localeAlias1425": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-tue-narrow-relative+-1": "last Tuesday",
	"field-second-narrow@localeAlias1426": {
		"bundle": "",
		"target": "field-second"
	},
	"days-standAlone-short@localeAlias1335": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"days-standAlone-short@localeAlias1336": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-short@localeAlias1337": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-sat-relative+-1": "last Saturday",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-tue-short@localeAlias1400": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"AH"
	],
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-zone-short@localeAlias1427": {
		"bundle": "",
		"target": "field-zone"
	},
	"days-format-narrow@localeAlias1330": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-dayperiod-narrow": "Dayperiod",
	"field-week-narrow@localeAlias1377": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-sun-short-relative+-1": "last Sunday",
	"field-week-narrow@localeAlias1378": {
		"bundle": "",
		"target": "field-week"
	},
	"eraAbbr": [
		"AH"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dateTime@localeAlias1362": {
		"bundle": "islamic",
		"target": "dateTime"
	},
	"field-second-short@localeAlias1424": {
		"bundle": "",
		"target": "field-second"
	},
	"dateTime@localeAlias1363": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"dayPeriods-standAlone-wide-pm": "PM",
	"field-weekdayOfMonth-narrow@localeAlias1392": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias1393": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-minute-narrow@localeAlias1422": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias1423": {
		"bundle": "",
		"target": "field-minute"
	},
	"timeFormat@localeAlias1360": {
		"bundle": "islamic",
		"target": "timeFormat"
	},
	"timeFormat@localeAlias1361": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"dayPeriods-standAlone-wide@localeAlias1353": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias1354": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-mon-narrow@localeAlias1398": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-mon-narrow@localeAlias1399": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-sun-narrow@localeAlias1395": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias1396": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-dayOfYear-narrow@localeAlias1386": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-dayOfYear-narrow@localeAlias1387": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"dayPeriods@localeAlias1346": {
		"bundle": "islamic",
		"target": "dayPeriods"
	},
	"dayPeriods@localeAlias1347": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-second-relative+0": "now",
	"quarters-standAlone-wide@localeAlias1345": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-quarter-relative+-1": "last quarter",
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"quarters-format-abbr@localeAlias1341": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-weekOfMonth-narrow@localeAlias1380": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias1381": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-year": "Year",
	"field-sat-short@localeAlias1412": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-tue-narrow@localeAlias1401": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias1402": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-day-short-relative+-1": "yesterday",
	"dayPeriods-standAlone-narrow@localeAlias1351": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias1352": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "Hour",
	"field-weekdayOfMonth-short@localeAlias1391": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"dateFormatItem-yyyy": "G y",
	"field-day-short@localeAlias1382": {
		"bundle": "",
		"target": "field-day"
	},
	"days-format-abbr@localeAlias1329": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"field-era-narrow@localeAlias1365": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias1366": {
		"bundle": "",
		"target": "field-era"
	},
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"quarters-format-narrow@localeAlias1342": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dayPeriods-format-wide@localeAlias1349": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-fri-narrow@localeAlias1410": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias1411": {
		"bundle": "",
		"target": "field-fri"
	},
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-hour-narrow@localeAlias1419": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-hour-narrow@localeAlias1420": {
		"bundle": "",
		"target": "field-hour"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"eraNarrow@localeAlias1357": {
		"bundle": "islamic",
		"target": "eraAbbr"
	},
	"field-week-narrow-relative+-1": "last week",
	"field-day-narrow@localeAlias1383": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias1384": {
		"bundle": "",
		"target": "field-day"
	},
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-mon-short@localeAlias1397": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"dayPeriods-standAlone-abbr@localeAlias1350": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-hour-short@localeAlias1418": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-sun-short@localeAlias1394": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-fri-relative+-1": "last Friday",
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"days-standAlone-wide@localeAlias1338": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-abbr@localeAlias1343": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"field-zone-narrow@localeAlias1428": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"quarters-standAlone-abbr@localeAlias1344": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-zone-narrow@localeAlias1429": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"Muh.",
		"Saf.",
		"Rab. I",
		"Rab. II",
		"Jum. I",
		"Jum. II",
		"Raj.",
		"Sha.",
		"Ram.",
		"Shaw.",
		"Dhuʻl-Q.",
		"Dhuʻl-H."
	],
	"field-month-relative+0": "this month",
	"field-dayperiod-short@localeAlias1415": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormat@localeAlias1358": {
		"bundle": "islamic",
		"target": "dateFormat"
	},
	"dateFormat@localeAlias1359": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"field-thu-narrow@localeAlias1407": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-thu-narrow@localeAlias1408": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-quarter-narrow-relative+0": "this quarter",
	"dayPeriods-format-narrow@localeAlias1348": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-weekday-narrow@localeAlias1389": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-year-narrow-relative+0": "this year",
	"field-year-short@localeAlias1367": {
		"bundle": "",
		"target": "field-year"
	},
	"field-year-narrow-relative+1": "next year",
	"field-sat-narrow@localeAlias1413": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias1414": {
		"bundle": "",
		"target": "field-sat"
	},
	"dateFormatItem-Gy": "G y",
	"field-zone-narrow": "Zone",
	"field-fri-short@localeAlias1409": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-week-short@localeAlias1376": {
		"bundle": "",
		"target": "field-week"
	},
	"months-standAlone-wide@localeAlias1326": {
		"bundle": "islamic",
		"target": "months-format-wide"
	},
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"days@localeAlias1327": {
		"bundle": "islamic",
		"target": "days"
	},
	"field-tue-relative+-1": "last Tuesday",
	"days@localeAlias1328": {
		"bundle": "gregorian",
		"target": "days"
	},
	"quarters@localeAlias1339": {
		"bundle": "islamic",
		"target": "quarters"
	},
	"field-minute-short": "Minute",
	"field-weekday-narrow@localeAlias1390": {
		"bundle": "",
		"target": "field-weekday"
	},
	"dateFormatItem-Hm": "HH:mm",
	"era@localeAlias1355": {
		"bundle": "islamic",
		"target": "era"
	},
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"field-month-short@localeAlias1373": {
		"bundle": "",
		"target": "field-month"
	},
	"quarters@localeAlias1340": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"dateFormatItem-MMM": "LLL",
	"field-dayperiod-narrow@localeAlias1416": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-sun-relative+0": "this Sunday",
	"field-dayperiod-narrow@localeAlias1417": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-sun-relative+1": "next Sunday",
	"field-wed-narrow@localeAlias1404": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-wed-narrow@localeAlias1405": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
});